@@ -1,6 +1,14 @@
 from .lambda_function import LambdaFunction
-import json
+import simplejson as json
 import re
+import decimal
+
+
+# class DecimalEncoder(json.JSONEncoder):
+#     def _iterencode(self, o, markers=None):
+#         if isinstance(o, decimal.Decimal):
+#             return (str(o) for o in [o])
+#         return super(DecimalEncoder, self)._iterencode(o, markers)
 
 
 class APIFunction(LambdaFunction):
